#
# spec file for package python-pbr
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# NOTE(saschpe): git invocation and pythonpath issues with testrepository
# enable testing with a build conditional (off by default):
%bcond_with test

Name:           python-pbr
Version:        1.8.0
Release:        4.1
Summary:        Python Build Reasonableness
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://pypi.python.org/pypi/pbr
Source:         https://pypi.python.org/packages/source/p/pbr/pbr-%{version}.tar.gz
Source1:        python-pbr-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-pip >= 1.4
# Test requirements:
%if %{with test}
#BuildRequires:  python-coverage >= 3.6
%if 0%{?suse_version} <= 1110
BuildRequires:  python-discover
%endif
BuildRequires:  python-fixtures >= 0.3.14
BuildRequires:  python-hacking >= 0.9.2
BuildRequires:  python-mock >= 1.2
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testresources >= 0.2.4
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 0.9.34
%endif
Requires:       python-pip >= 1.4
%if 0%{?suse_version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
%else
Requires(post): chkconfig
Requires(postun): chkconfig
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%{!?py_ver:     %global py_ver     %(python -c "import sys; v=sys.version_info[:2]; print '%%d.%%d'%%v" 2>/dev/null || echo PYTHON-NOT-FOUND)}
%endif

%description
PBR is a library to automatically do a bunch of standard
things you want in your setup.py without you having to repeat
them every time. It will set versions, process requirements
files and generate AUTHORS and ChangeLog file all from git
information.

%prep
%setup -q -n pbr-%{version}
# Get rid of ugly build-time deps that require network:
sed -i "s/, 'sphinx\.ext\.intersphinx'//" doc/source/conf.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/pbr %{buildroot}%{_bindir}/pbr-%{py_ver}
ln -s -f %{_sysconfdir}/alternatives/pbr %{buildroot}%{_bindir}/pbr
# create a dummy target for /etc/alternatives/pbr
touch %{buildroot}%{_sysconfdir}/alternatives/pbr
%fdupes -s %{buildroot}%{python_sitelib}

%if %{with test}
%check
testr init && testr run --parallel
%endif

%post
%_sbindir/update-alternatives \
    --install %{_bindir}/pbr pbr %{_bindir}/pbr-%{py_ver} 20

%preun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove pbr %{_bindir}/pbr-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog CONTRIBUTING.rst LICENSE README.rst
%{python_sitelib}/pbr
%{python_sitelib}/pbr-%{version}-py%{py_ver}.egg-info
%{_bindir}/pbr-%{py_ver}
%{_bindir}/pbr
%ghost %{_sysconfdir}/alternatives/pbr

%changelog
* Wed Jun 22 2016 kkaempf@suse.com
- chkconfig provides update-alternatives on RHEL
* Sun Sep 20 2015 tbechtold@suse.com
- update to 1.8.0:
  * Strip comments present in setup.cfg
  * Protect WSGI application with a critical section
- Remove 0001-Remove-sphinx_config.init_values-manual-call.patch
  Fixed upstream
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.7.0:
  * Have pbr egg_info.writer check PBR is enabled
* Wed Aug 26 2015 tbechtold@suse.com
- update to 1.6.0:
  * Strip comments in requirements files
  * Handle git being entirely absent
  * We require the use of setuptools
  * Fix retrieval of commit data and most recent tag
- Remove 0001-Handle-git-being-entirely-absent.patch .
  Applied upstream
* Wed Aug 12 2015 dmueller@suse.com
- add 0001-Handle-git-being-entirely-absent.patch
- revert dependency on git (see comment in the specfile)
* Tue Aug 11 2015 seife+obs@b1-systems.com
- update to version 1.4.0
  * Fix docs for environment markers in extras
  * Export ChangeLog and AUTHORS in install
  * Show how long the git querying takes
  * Add wsgi_scripts support to PBR
  * Updated from global requirements
- requires python-mock >= 1.2
* Mon Aug  3 2015 toddrme2178@gmail.com
- Actually remove documentation requirements
* Mon Aug  3 2015 toddrme2178@gmail.com
- Split documentation into own package to avoid dependency loop
* Mon Jul 27 2015 toddrme2178@gmail.com
- Fix update-alternatives usage.
* Fri Jul 17 2015 tbechtold@suse.com
- update to 1.3.0:
  * Wrap env markers in parens
  * Updated from global requirements
  * Add more documentation around building docs
  * Updated from global requirements
  * Use string for 'OS_TEST_TIMEOUT' default
  * Updated from global requirements
  * This documents the use of comments that work between 2.6, 2.7 and 3.4
- Add 0001-Remove-sphinx_config.init_values-manual-call.patch . Needed
  for newer Sphinx versions.
* Wed Jun 24 2015 dmueller@suse.com
- update to 1.2.0:
  * Strip markers from test requirements
  * Revert "Remove sphinx_config.init_values(
* Tue Jun  9 2015 tbechtold@suse.com
- update to 1.1.0:
  * Fix test case to be runnable with gnupg 2.1
  * More explicit data_files install location docs
  * Move CapturedSubprocess fixture to base
  * Remove sphinx_config.init_values() manual call
  * Updated from global requirements
  * builddoc: allow to use fnmatch-style exclusion for autodoc
  * doc: add some basic doc about pbr doc options
  * Add home-page into sample setup.cfg
  * Make setup.py --help-commands work without testrepository
- Removed 0001-Remove-sphinx_config.init_values-manual-call.patch
  Applied upstream.
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.0.1:
  * Remove self.pre_run calls in packaging.py
  * Update hacking to 0.10.x series
  * Teach pbr to read extras and env markers
  * Bump integration test timeouts
  * Finish removing invocations of pip
  * Advertise support for Python3.4
  * Issue #1451976: handle commits with non-utf8 text
  * Parallelise integration tests
- Removed pbr-0.10.8-fix-sphinx-init_values.patch . Replaced upstream
  with 0001-Remove-sphinx_config.init_values-manual-call.patch
- Added 0001-Remove-sphinx_config.init_values-manual-call.patch
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 0.11.0:
  * Issue #1450210: Preversioning rc tag handling
  * Stop testing setup.py easy_install behaviour
  * Test pip install -e of projects
  * Build all the wheels in one pass rather than many
  * Improve integration.sh
  * Honour new test variable PIPVERSION
  * Be safe, don't let friends use RawConfigParser
  * Revert "Support platform-specific requirements files"
  * Reinstate pure-git-hashes-are-illegal test
  * Ignore non-release related tags
  * Test that MANIFEST.in excludes work
  * Fixup semver
  * Better diagnostics on test failure
  * Don't avoid egg-info quite so often
  * Add truncated lincense text
  * "packages" might list multiple directories
  * Support script text override for newer develop
  * Fixes Windows generated scripts headers
  * Update README format to match release notes tool
  * Be more aggressive about building wheels
  * Use a wheelhouse in the integration test
  * Build a wheel when integration testing PBR changes
  * Use unsafe OpenPGP keys for testing
- increase required version of python-hacking for the tests
* Thu Apr 16 2015 hpj@urpla.net
- Update to version 0.10.8
  * Support script text override for newer develop
- Changes from version 0.10.7
  * _get_revno only returns a commit count
- Changes from 0.10.6
  * Integration test PBR commits
- Changes from 0.10.5
  * Move write_pbr_json to avoid issues with nose
- Changes from 0.10.4
  * Properly check for git before getting git dir
  * Use post version signifiers
  * Only import sphinx during hook processing
- Changes from 0.10.3
  * Stop including git sha in version strings
  * Write and read more complex git sha info
- Changes from 0.10.2
  * Remove all 2.7 filtering
  * Stop filtering out argparse
  * Remove mirror testing from the integration script
- Changes from 0.10.1
  * Prefix git suffixes with + instead of
- fix Sphinx config.init_values fallout
- add update-alternatives
- remove outdated patches
  * 0001-use-get_boolean_option-for-warnerrors.patch
  * 0001-Allow-overwriting-sphinx-builder-list-from-command-l.patch
- Add pbr-0.10.8-fix-sphinx-init_values.patch
- put docs in its own package
* Fri Oct 24 2014 toddrme2178@gmail.com
- Add python-pip from requires to buildrequires
* Thu Aug 28 2014 dmueller@suse.com
- add 0001-Allow-overwriting-sphinx-builder-list-from-command-l.patch
  0001-use-get_boolean_option-for-warnerrors.patch
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Sat Jul 26 2014 tbechtold@suse.com
- Update BuildRequires according to test-requirements.txt
- Update to version 0.10.0
  * Remove all 2.7 filtering
  * Stop filtering out argparse
  * Remove mirror testing from the integration script
  0.9.0
  * Allow examining parsing exceptions
  * Update integration script for Apache 2.4
  * Restore Monkeypatched Distribution Instance
  * Register testr as a distutil entry point
  * Check for git before querying it for a version
  * Allow _run_cmd to run commands in any directory
  * Make setUp fail if sdist fails
  * Permit pre-release versions with git metadata
  * Un-nest some sections of code
  0.8.2
  * Remove --use-mailmap as it's not needed
  * Fix typos in docs
  0.8.1
  * pbr/testr_command.py: Add logging
  * Documentation updates
  * Fixed a typo in the documentation
  * Make source configurable when using --coverage
  * README.rst: tweaks
  * Format autoindex.rst file properly
  * make pbr use hacking directly
* Fri Mar 28 2014 speilicke@suse.com
- Update to version 0.8.0:
  * Use unicode_literals import instead of u'unicode' notation
  * Remove pip version specifier
  * Make tools/integration.sh take a branch
  * Fixes blocking issue on Windows
* Mon Mar 24 2014 dmueller@suse.com
- update to 0.7.0:
  * No changes, just use the released tarball which has
  the right version (that others are checking for)
* Tue Mar 18 2014 speilicke@suse.com
- Update to version pbr-0.6.14.g6ffff7c:
  * Factor run_cmd out of the base class
  * Return the real class in VersionInfo __repr__
  * Fix up some docstrings
  * Init sphinx config values before accessing them
  * Remove copyright from empty files
  * Declare support for Python versions in setup.cfg
  * Updated from global requirements
  * Remove unused _parse_mailmap()
  * Add support for python 3-<3.3
  * Remove tox locale overrides
  * Do not force log verbosity level to info
  0.6
  * package: read a specific Python version requirement file
- Fix dependencies
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Tue Feb  4 2014 dmueller@suse.com
- update to 0.6:
  * package: read a specific Python version requirement file
  * Fix typos in documents
  * Pin sphinx to <1.2
  * Build mirror using proper requirements
  * Use wheels for installation
  * show diff between pip installed packages and requirements
  * Enable wheel processing in the tests
  * Clean up integration script
  * Let git do mailmap mapping for us
  * Make ChangeLog more condensed
  * Make sphinx builders configurable in LocalBuildDoc
  * Serve local mirror using apache
  * Bump the development status classifier
  * Support building wheels (PEP-427)
  * Ignore jenkins@openstack.org in authors building
  * Communicate to user when we skip a requirement
  * Base python 2.7 skip list on parsed names
  * Link to the documentation in the readme
  * Avoid using 'which' executable for finding git
  * Add wheel mirror structure awareness
  * Remove pip as an argument from mkvenv
  * Use pypi-mirror instead of jeepyb
* Thu Jan  9 2014 speilicke@suse.com
- Update to version 0.5.23.36.g00fbbd1:
- Install from tarballs.openstack.org (rather than PyPI) and use _service file
* Mon Nov 25 2013 speilicke@suse.com
- Update dependencies
- Rename build-conditional to "test", avoid clash with Cloud:OpenStack:Master's
  "tests" build-conditional. We've got other issues here
- Add rpmlintrc, we have some C files as part of the testsuite
* Thu Oct 31 2013 dmueller@suse.com
- update to 0.5.23:
  * Use dev based release versioning
* Thu Aug  8 2013 speilicke@suse.com
- Update to version 0.5.21:
  + Replace setuptools_git with a smarter approach
* Mon Aug  5 2013 speilicke@suse.com
- Add python-pip requirement
* Sun Aug  4 2013 dmueller@suse.com
- update to 0.5.20:
  * Add support for globbing in data files
  * Stop trying to install old pip and setuptools
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.5.18:
  * support python setup.py test
  * various python 3.x compat fixes
* Thu Jul  4 2013 speilicke@suse.com
- Introduce a build conditional for running tests to break build cycle
  with python-oslo.config
* Tue Jul  2 2013 dmueller@suse.com
- update description
* Wed Jun 26 2013 cdenicolo@suse.com
- license update: Apache-2.0
  license SUSE-Xano license not found in package. See LICENSE file.
* Wed Jun 26 2013 dmueller@suse.com
- remove python-discover dependency for newer distros
* Fri Jun 21 2013 dmueller@suse.com
- update to 0.5.17:
  * Remove dependency on distribute
  * Fix pip invocation for old versions of pip.
- remove 0001-Use-pip-instead-of-easy_install-for-installation.patch
- remove 0001-Skip-git-checkout-related-tests-when-.git-is-missing.patch
* Mon Jun 10 2013 dmueller@suse.com
- add 0001-Use-pip-instead-of-easy_install-for-installation.patch
* Mon Jun 10 2013 dmueller@suse.com
- update to 0.5.14:
  * Remove jinja pin.
  * Explicitly install install_requires.
  * More python3 compatibility.
  * Fix tox.ini to not reference deleted testenv
  * Fix doc autoindexing.
  * Add missing files to the tarball.
- add 0001-Skip-git-checkout-related-tests-when-.git-is-missing.patch
* Mon May 27 2013 dmueller@suse.com
- update to 0.5.10:
  + Default to single-version-externally-managed
  + Add config for skipping authors and changelog.
  + Update to d2to1 0.2.10.
* Tue May  7 2013 speilicke@suse.com
- Buildrequire python-python-mimeparse and use testr instead of nosetests.
  The pbr testsuite needs some proper setup to pass successfully.
* Thu May  2 2013 speilicke@suse.com
- Initial version
